# Users - Gmail - Profile
- [API documentation](#api-documentation)
- [Definitions](#definitions)
- [Display Gmail profile](#display-gmail-profile)

## API documentation
* [Gmail API - Profile](https://developers.google.com/gmail/api/v1/reference/users/getProfile)

## Definitions
* [`<UserTypeEntity>`](Collections-of-Users)

## Display Gmail profile
```
gam <UserTypeEntity> show gmailprofile
gam <UserTypeEntity> print gmailprofile [todrive <ToDriveAttribute>*]
```
